@@ -2,7 +2,7 @@ package App::githook_perltidy;
 use strict;
 use OptArgs;
 
-our $VERSION = '0.11.1';
+our $VERSION = '0.11.2';
 
 arg command => (
     isa      => 'SubCmd',
@@ -53,6 +53,10 @@ __END__
 
 App::githook_perltidy - dispatch module for githook-perltidy.
 
+=head1 VERSION
+
+0.11.2 (2016-01-20)
+
 =head1 SEE ALSO
 
 L<githook-perltidy>(1)
