@@ -5,7 +5,7 @@ use App::githook_perltidy::Util qw/get_perltidyrc/;
 use File::Basename;
 use Path::Tiny;
 
-our $VERSION = '0.11.1';
+our $VERSION = '0.11.2';
 
 sub run {
     my $opts = shift;
@@ -56,7 +56,7 @@ App::githook_perltidy::install - install git hooks
 
 =head1 VERSION
 
-0.11.1.
+0.11.2 (2016-01-20)
 
 =head1 SEE ALSO
 
