@@ -8,7 +8,7 @@ use Perl::Tidy;
 use Pod::Tidy;
 use Time::Piece;
 
-our $VERSION = '0.11.1';
+our $VERSION = '0.11.2';
 
 my $stashed;
 my $success;
@@ -51,8 +51,8 @@ sub run {
 
                 #        warn $possible;
                 next
-                  unless $possible =~ m/^#!.*perl\W/
-                  or $possible =~ m/^#!.*\.plenv\W/;
+                  unless $possible =~ m/^#!.*perl/
+                  or $possible =~ m/^#!.*\.plenv/;
             }
 
             push( @perlfiles, $file );
@@ -177,7 +177,7 @@ App::githook_perltidy::pre_commit - git pre-commit hook
 
 =head1 VERSION
 
-0.11.1.
+0.11.2 (2016-01-20)
 
 =head1 SEE ALSO
 
